.. _sec_advanced_scripting:

==============
Advanced Usage
==============
This section motivates the design of dclab and highlights useful built-in
functionalities.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   sec_av_notation
   sec_av_rtdc_dataset
   sec_av_scatter
   sec_av_fluorescence
